@@ -3,6 +3,6 @@ from crocs.regex import Pattern, Include,Any
 e = Any(Include('a', 'b', 'c'), '1')
 
 regstr = e.mkregex()
-print(regstr)
-
+e.test()
+e.hits()
 
