@@ -632,6 +632,70 @@ class TestAny(unittest.TestCase):
         clone = yregex.mkclone()
         self.assertEqual(clone.mkregex(), regstr)
 
+    def test15(self):
+        regstr = r'a|b|c+'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test16(self):
+        regstr = r'(a+|b*|c+)(\1ff)((\2ee))\3*|rs+|rss*'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test17(self):
+        regstr = r'(a+|b*|c+)(\1ff)((\2ee))\3*|((a+cee*ee+c{1,}?)ee)'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test18(self):
+        regstr = r'(a+|b*|c+)(\1ff)((\2ee))\3*|((a+cee*ee+c{1,}?)ee)|((a.+c)cd.*)(?=f.+bar)'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test19(self):
+        regstr = r'(a+|b*|(?<=abc..d)(((ss))c+))(f+f)((ee))*|((a+cee*ee+c{1,}?)ee)|((a.+c)cd.*)(?=f.+bar)'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test20(self):
+        regstr = r'(((e(a|b|c)d)c)|((ab|cd)|ef)|((((a|e|u|i+))))|ef)|ee|oo|.+'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test21(self):
+        regstr = r'a.+?|e.*?|c{1,2}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+
 class TestOneOrZero(unittest.TestCase):
     def test0(self):
         expr0 = Include(Seq('0', '9'))
@@ -892,7 +956,7 @@ class TestRepeat(unittest.TestCase):
     def test0(self):
         expr0 = NamedGroup('oooo', Repeat(Group(Any('a', X(), 'b'))))
         expr1 = Any(expr0, 'm', 'n', Group('oooo'), Group(expr0, X(), '12oooo', X()))
-        expr2 = Repeat(Group(expr1))
+        expr2 = Repeat(Group(expr1), 1, 3)
         expr3 = Pattern(expr0, Group(expr1), expr2)
 
         regstr = expr3.mkregex()
